@@ -1,7 +1,46 @@
 package App::CharmKit::Role::Lint;
-$App::CharmKit::Role::Lint::VERSION = '1.0.6';
+
 # ABSTRACT: charm linter
 
+=head1 SYNOPSIS
+
+  $ charmkit lint
+
+=head1 DESCRIPTION
+
+Performs various lint checks to make sure the charm is in accordance with
+Charm Store policies.
+
+=head1 Format of lint rules
+
+Lint rules are loaded from B<lint_rules.yaml> in the distributions share directory.
+The format for rules is as follows:
+
+  ---
+  files:
+    file:
+      name: 'config.yaml'
+      attributes:
+        - NOT_EMPTY
+        - EXISTS
+    file:
+      name: 'copyright'
+      attributes:
+        - NOT_EMPTY
+        - EXISTS
+      parse:
+        - pattern: '^options:\s*\n'
+          error: 'ERR_INVALID_COPYRIGHT'
+
+=attr rules
+
+Lint rules file
+
+=attr has_error
+
+Stores whether or not a fatal error was found
+
+=cut
 use strict;
 use warnings;
 use boolean;
@@ -10,13 +49,17 @@ use Path::Tiny;
 use File::ShareDir qw(dist_file);
 use Set::Tiny;
 use Email::Address;
-use App::CharmKit::Logging qw/prettyLog/;
 
 use Class::Tiny {
     rules => YAML::Tiny->read(dist_file('App-CharmKit', 'lint_rules.yaml')),
     has_error => 0
 };
 
+=method parse
+
+Parses charm
+
+=cut
 sub parse {
     my ($self) = @_;
 
@@ -54,6 +97,11 @@ sub parse {
 }
 
 
+=method validate_tests
+
+Does basic sanity checking on tests directory
+
+=cut
 
 sub validate_tests {
     my ($self) = @_;
@@ -63,6 +111,11 @@ sub validate_tests {
       if ($tests_path->child('00-autogen')->exists);
 }
 
+=method validate_configdata
+
+Validates B<config.yaml>
+
+=cut
 sub validate_configdata {
     my ($self, $configdata) = @_;
     my $config_on_disk = YAML::Tiny->read($configdata->{name})->[0];
@@ -112,6 +165,11 @@ sub validate_configdata {
 }
 
 
+=method validate_metadata
+
+Validates B<metadata.yaml>
+
+=cut
 sub validate_metadata {
     my ($self, $metadata) = @_;
     my $meta_on_disk = YAML::Tiny->read($metadata->{name})->[0];
@@ -257,6 +315,11 @@ sub validate_metadata {
 }
 
 
+=method validate_hook
+
+Validates charm hooks
+
+=cut
 sub validate_hook {
     my ($self, $hookmeta) = @_;
     my $filepath = path('hooks')->child($hookmeta->{name});
@@ -275,6 +338,18 @@ sub validate_hook {
     }
 }
 
+=method validate_attributes
+
+Performs validation of file based on available attribute
+
+=head2 Available Attributes
+
+=for :list
+* NOT_EMPTY
+* NOT_EXISTS
+* EXISTS
+
+=cut
 
 sub validate_attributes {
     my ($self, $filemeta) = @_;
@@ -304,6 +379,11 @@ sub validate_attributes {
     }
 }
 
+=method lint_fatal
+
+Prints a FATAL lint message
+
+=cut
 sub lint_fatal {
     my ($self, $item, $message) = @_;
     $self->has_error(1);
@@ -315,6 +395,11 @@ sub lint_fatal {
     );
 }
 
+=method lint_warn
+
+Prints a WARNING lint message
+
+=cut
 sub lint_warn {
     my ($self, $item, $message) = @_;
     $self->lint_print(
@@ -325,6 +410,11 @@ sub lint_warn {
     );
 }
 
+=method lint_info
+
+Prints a INFO lint message
+
+=cut
 sub lint_info {
     my ($self, $item, $message) = @_;
     $self->lint_print(
@@ -335,6 +425,11 @@ sub lint_info {
     );
 }
 
+=method lint_print
+
+Prints out lint errors
+
+=cut
 sub lint_print {
     my ($self, $item, $error) = @_;
     printf("%s: (%s) %s\n",
@@ -343,153 +438,3 @@ sub lint_print {
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-App::CharmKit::Role::Lint - charm linter
-
-=head1 VERSION
-
-version 1.0.6
-
-=head1 SYNOPSIS
-
-  $ charmkit lint
-
-=head1 DESCRIPTION
-
-Performs various lint checks to make sure the charm is in accordance with
-Charm Store policies.
-
-=head1 ATTRIBUTES
-
-=head2 rules
-
-Lint rules file
-
-=head2 has_error
-
-Stores whether or not a fatal error was found
-
-=head1 METHODS
-
-=head2 parse
-
-Parses charm
-
-=head2 validate_tests
-
-Does basic sanity checking on tests directory
-
-=head2 validate_configdata
-
-Validates B<config.yaml>
-
-=head2 validate_metadata
-
-Validates B<metadata.yaml>
-
-=head2 validate_hook
-
-Validates charm hooks
-
-=head2 validate_attributes
-
-Performs validation of file based on available attribute
-
-=head2 lint_fatal
-
-Prints a FATAL lint message
-
-=head2 lint_warn
-
-Prints a WARNING lint message
-
-=head2 lint_info
-
-Prints a INFO lint message
-
-=head2 lint_print
-
-Prints out lint errors
-
-=head1 Format of lint rules
-
-Lint rules are loaded from B<lint_rules.yaml> in the distributions share directory.
-The format for rules is as follows:
-
-  ---
-  files:
-    file:
-      name: 'config.yaml'
-      attributes:
-        - NOT_EMPTY
-        - EXISTS
-    file:
-      name: 'copyright'
-      attributes:
-        - NOT_EMPTY
-        - EXISTS
-      parse:
-        - pattern: '^options:\s*\n'
-          error: 'ERR_INVALID_COPYRIGHT'
-
-=head2 Available Attributes
-
-=over 4
-
-=item *
-
-NOT_EMPTY
-
-=item *
-
-NOT_EXISTS
-
-=item *
-
-EXISTS
-
-=back
-
-=head1 AUTHOR
-
-Adam Stokes <adamjs@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Adam Stokes.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
-WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
-PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
-EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
-IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
-SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
-THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
-TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
-SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
-DAMAGES.
-
-=cut
